import 'dart:io';

import 'package:danger_core/danger_core.dart';

class DangerDartAnalyse {
  static void processFile(File file) {
    if (!file.existsSync()) {
      fail('Flutter analyse report [${file.path}] not found');
      return;
    }

    final lines = file
        .readAsLinesSync()
        .map((l) => l.trim())
        .where((l) => l.isNotEmpty && !l.contains('No issues found!'))
        .toList();

    if (lines.isNotEmpty) {
      for (var line in lines) {
        final splittedLine = line.split('•');
        final issueType = splittedLine[0].trim();
        final message = splittedLine[1].trim();
        final fileInfo = splittedLine[2].trim().split(':');
        final filePath = fileInfo[0];
        final fileLine = fileInfo[1];
        final ruleName = splittedLine[3].trim();

        if (issueType == 'info') {
          warn('Please correct this warning: $message ($ruleName)',
              file: filePath, line: int.tryParse(fileLine) ?? 0);
        } else {
          warn('Please correct this error: $message ($ruleName)',
              file: filePath, line: int.tryParse(fileLine) ?? 0);
        }
      }
    }
  }
}
